import { o as MalAnimeListRequest, p as MalAnimeListResponse, s as MalAnimeDetailsRequest, r as MalAnimeDetails, v as MalAnimeRankingRequest, w as MalAnimeRankingResponse, z as MalAnimeSeasonalRequest, A as MalAnimeSeasonalResponse, B as MalAnimeSuggestionsRequest } from '../../mal-manga.model-BSnTz6i5.cjs';
import { MalClientEndpoint } from '../../models/mal-client.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const anime: {
    /**
     * Get anime list.
     *
     * @pagination true
     * @nsfw true
     * @auth client or user
     *
     * @see [anime-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_get}
     */
    list: MalClientEndpoint<MalAnimeListRequest, MalAnimeListResponse, true>;
    /**
     * Get anime details.
     *
     * @auth client or user
     *
     * @see [anime-details]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_anime_id_get}
     */
    details: MalClientEndpoint<MalAnimeDetailsRequest, MalAnimeDetails, true>;
    /**
     * Get anime rankings.
     *
     * @pagination true
     * @auth client or user
     * @nsfw true
     *
     * @see [anime-rankings]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_ranking_get}
     */
    ranking: MalClientEndpoint<MalAnimeRankingRequest, MalAnimeRankingResponse, true>;
    /**
     * Get list of anime airing for season.
     *
     * @auth client or user
     * @pagination true
     * @nsfw true
     *
     * @see [anime-seasonal]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_season_year_season_get}
     */
    seasonal: MalClientEndpoint<MalAnimeSeasonalRequest, MalAnimeSeasonalResponse, true>;
    /**
     * Get list of suggested anime for a specific anime.
     *
     * Returns suggested anime for the authorized user.
     *
     * If the user is new comer, this endpoint returns an empty list.
     *
     * @auth user
     * @pagination true
     * @nsfw true
     *
     *@see [anime-suggestions]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_suggestions_get}
     */
    suggestions: MalClientEndpoint<MalAnimeSuggestionsRequest, MalAnimeListResponse, true>;
};

export { anime };
