import { MalForumBoardsResponse, MalForumListTopicsRequest, MalForumListTopicsResponse, MalForumTopicDetailRequest, MalForumTopicDetailResponse } from '../../models/mal-forum.model.js';
import { MalClientEndpoint } from '../../models/mal-client.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const forum: {
    /**
     * Get forum boards
     *
     * @auth client or user
     *
     * @see [forum-boards]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_boards_get}
     */
    boards: MalClientEndpoint<Record<string, never>, MalForumBoardsResponse, true>;
    topics: {
        /**
         * Get forum topics
         *
         * @auth client or user
         * @pagination true
         *
         * @see [forum-topics]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_topics_get}
         */
        list: MalClientEndpoint<MalForumListTopicsRequest, MalForumListTopicsResponse, true>;
        /**
         * Get forum topic details
         *
         * @auth client or user
         * @pagination true
         *
         * @see [forum-topic-details]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_topic_get
         */
        details: MalClientEndpoint<MalForumTopicDetailRequest, MalForumTopicDetailResponse, true>;
    };
};

export { forum };
