import { E as MalAnimeUserListRequest, F as MalAnimeUserListResponse, G as MalAnimeUserListUpdateRequest, d as MalAnimeMyListStatus, af as MalMangaUserListRequest, ag as MalMangaUserListResponse, ah as MalMangaUserListUpdateRequest, $ as MalMangaMyListStatus } from '../../mal-manga.model-BSnTz6i5.cjs';
import { MalUserRequest, MalUser } from '../../models/mal-user.model.cjs';
import { MalClientEndpoint } from '../../models/mal-client.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const user: {
    /**
     * Get user information.
     *
     * @auth user
     *
     * @see [user-info]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/users_user_id_get}
     */
    info: MalClientEndpoint<MalUserRequest, MalUser, true>;
    list: {
        anime: {
            /**
             * Get the user's anime list.
             *
             * @auth user or client
             * @pagination true
             * @nsfw true
             *
             * @see [user-anime-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/users_user_id_animelist_get}
             */
            get: MalClientEndpoint<MalAnimeUserListRequest, MalAnimeUserListResponse, true>;
            /**
             * Add specified anime to my anime list.
             *
             * If specified anime already exists, update its status.
             *
             * This endpoint updates only values specified by the parameter.
             *
             * @auth user
             *
             * @see [user-update-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_anime_id_my_list_status_put}
             */
            update: MalClientEndpoint<MalAnimeUserListUpdateRequest, MalAnimeMyListStatus, false>;
            /**
             * If the specified anime does not exist in user's anime list, this endpoint does nothing and returns 404 Not Found.
             *
             * So be careful when retrying.
             *
             * @auth user
             *
             * @see [user-delete-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/anime_anime_id_my_list_status_delete}
             */
            delete: MalClientEndpoint<{
                anime_id: string | number;
            }, unknown, false>;
        };
        manga: {
            /**
             * Get the user's manga list.
             *
             * @auth user or client
             * @pagination true
             * @nsfw true
             *
             * @see [user-manga-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/users_user_id_mangalist_get}
             */
            get: MalClientEndpoint<MalMangaUserListRequest, MalMangaUserListResponse, true>;
            /**
             * Add specified manga to my manga list.
             *
             * If specified manga already exists, update its status.
             *
             * This endpoint updates only values specified by the parameter.
             *
             * @auth user
             *
             * @see [user-update-manga-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/manga_manga_id_my_list_status_put}
             */
            update: MalClientEndpoint<MalMangaUserListUpdateRequest, MalMangaMyListStatus, false>;
            /**
             * @see [user-delete-manga-list]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/manga_manga_id_my_list_status_delete}
             */
            delete: MalClientEndpoint<{
                manga_id: string | number;
            }, unknown, false>;
        };
    };
};

export { user };
