import { MalForumBoardsResponse, MalForumListTopicsRequest, MalForumListTopicsResponse, MalForumTopicDetailRequest, MalForumTopicDetailResponse } from '../models/mal-forum.model.js';
import { MalUserRequest, MalUser } from '../models/mal-user.model.js';
import { o as MalAnimeListRequest, p as MalAnimeListResponse, s as MalAnimeDetailsRequest, r as MalAnimeDetails, v as MalAnimeRankingRequest, w as MalAnimeRankingResponse, z as MalAnimeSeasonalRequest, A as MalAnimeSeasonalResponse, B as MalAnimeSuggestionsRequest, a3 as MalMangaListRequest, a4 as MalMangaListResponse, a8 as MalMangaDetailsRequest, a7 as MalMangaDetails, ab as MalMangaRankingRequest, ac as MalMangaRankingResponse, E as MalAnimeUserListRequest, F as MalAnimeUserListResponse, G as MalAnimeUserListUpdateRequest, d as MalAnimeMyListStatus, af as MalMangaUserListRequest, ag as MalMangaUserListResponse, ah as MalMangaUserListUpdateRequest, $ as MalMangaMyListStatus } from '../mal-manga.model-C0nLfefh.js';
import { MalClientEndpoint } from '../models/mal-client.model.js';
import { MalAuthorizeRequest, MalTokenExchangeRequest, MalAuthenticationToken, MalTokenRefreshRequest } from '../models/mal-authentication.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

/**
 * @see [documentation]{@link https://myanimelist.net/apiconfig/references/api/v2}
 */
declare const malApi: {
    authentication: {
        authorize: MalClientEndpoint<MalAuthorizeRequest, unknown, false>;
        token: {
            exchange: MalClientEndpoint<MalTokenExchangeRequest, MalAuthenticationToken, false>;
            refresh: MalClientEndpoint<MalTokenRefreshRequest, MalAuthenticationToken, false>;
        };
    };
    anime: {
        list: MalClientEndpoint<MalAnimeListRequest, MalAnimeListResponse, true>;
        details: MalClientEndpoint<MalAnimeDetailsRequest, MalAnimeDetails, true>;
        ranking: MalClientEndpoint<MalAnimeRankingRequest, MalAnimeRankingResponse, true>;
        seasonal: MalClientEndpoint<MalAnimeSeasonalRequest, MalAnimeSeasonalResponse, true>;
        suggestions: MalClientEndpoint<MalAnimeSuggestionsRequest, MalAnimeListResponse, true>;
    };
    manga: {
        list: MalClientEndpoint<MalMangaListRequest, MalMangaListResponse, true>;
        details: MalClientEndpoint<MalMangaDetailsRequest, MalMangaDetails, true>;
        ranking: MalClientEndpoint<MalMangaRankingRequest, MalMangaRankingResponse, true>;
    };
    user: {
        info: MalClientEndpoint<MalUserRequest, MalUser, true>;
        list: {
            anime: {
                get: MalClientEndpoint<MalAnimeUserListRequest, MalAnimeUserListResponse, true>;
                update: MalClientEndpoint<MalAnimeUserListUpdateRequest, MalAnimeMyListStatus, false>;
                delete: MalClientEndpoint<{
                    anime_id: string | number;
                }, unknown, false>;
            };
            manga: {
                get: MalClientEndpoint<MalMangaUserListRequest, MalMangaUserListResponse, true>;
                update: MalClientEndpoint<MalMangaUserListUpdateRequest, MalMangaMyListStatus, false>;
                delete: MalClientEndpoint<{
                    manga_id: string | number;
                }, unknown, false>;
            };
        };
    };
    forum: {
        boards: MalClientEndpoint<Record<string, never>, MalForumBoardsResponse, true>;
        topics: {
            list: MalClientEndpoint<MalForumListTopicsRequest, MalForumListTopicsResponse, true>;
            details: MalClientEndpoint<MalForumTopicDetailRequest, MalForumTopicDetailResponse, true>;
        };
    };
};
type MalApi = typeof malApi;

export { type MalApi, malApi };
