import {
  MalApiValidators
} from "./chunk-GY37KCB4.js";
import {
  ApiVersion,
  MalAuthType,
  MalClientEndpoint
} from "./chunk-BCMNSRGV.js";

// lib/api/endpoints/forum.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils";
var forum = {
  /**
   * Get forum boards
   *
   * @auth client or user
   *
   * @see [forum-boards]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_boards_get}
   */
  boards: new MalClientEndpoint({
    method: HttpMethod.GET,
    url: "/forum/boards",
    opts: {
      auth: MalAuthType.Both,
      version: ApiVersion.v2
    }
  }),
  topics: {
    /**
     * Get forum topics
     *
     * @auth client or user
     * @pagination true
     *
     * @see [forum-topics]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_topics_get}
     */
    list: new MalClientEndpoint({
      method: HttpMethod.GET,
      url: "/forum/topics",
      opts: {
        auth: MalAuthType.Both,
        version: ApiVersion.v2,
        pagination: {
          limit: 100,
          offset: 0
        },
        parameters: {
          query: {
            board_id: false,
            subboard_id: false,
            sort: false,
            q: false,
            topic_user_name: false,
            user_name: false,
            limit: false,
            offset: false
          }
        }
      },
      validate: (param) => {
        if (param.q) MalApiValidators.minLength(param.q, { min: 3, name: "q" });
        if (param.limit) MalApiValidators.minMax(param.limit, { min: 0, max: 100, name: "limit" });
        if (param.offset) MalApiValidators.min(param.offset, { min: 0, name: "offset" });
        return true;
      }
    }),
    /**
     * Get forum topic details
     *
     * @auth client or user
     * @pagination true
     *
     * @see [forum-topic-details]{@link https://myanimelist.net/apiconfig/references/api/v2#operation/forum_topic_get
     */
    details: new MalClientEndpoint({
      method: HttpMethod.GET,
      url: "/forum/topic/:id",
      opts: {
        auth: MalAuthType.Both,
        version: ApiVersion.v2,
        pagination: {
          limit: 100,
          offset: 0
        },
        parameters: {
          path: {
            id: true
          },
          query: {
            limit: false,
            offset: false
          }
        }
      },
      validate: (param) => {
        if (param.limit) MalApiValidators.minMax(param.limit, { min: 0, max: 100, name: "limit" });
        if (param.offset) MalApiValidators.min(param.offset, { min: 0, name: "offset" });
        return true;
      }
    })
  }
};

export {
  forum
};
