import {
  MalMaxValidationError,
  MalMinMaxValidationError,
  MalMinValidationError,
  MalNaNValidationError
} from "./chunk-EZCSSTDX.js";

// lib/api/validators/mal-api.validators.ts
var MalApiValidators = {
  isNumber: (value, name) => {
    const _value = Number(value);
    if (Number.isNaN(_value)) throw new MalNaNValidationError(value, name);
    return _value;
  },
  max: (value, { max, name }) => {
    const _value = MalApiValidators.isNumber(value);
    if (_value > max) throw new MalMaxValidationError({ value: _value, max, name });
    return _value;
  },
  min: (value, { min, name }) => {
    const _value = MalApiValidators.isNumber(value);
    if (_value < min) throw new MalMinValidationError({ value: _value, min, name });
    return _value;
  },
  minMax: (value, { min, max, name }) => {
    const _value = MalApiValidators.isNumber(value);
    if (_value < min || _value > max) throw new MalMinMaxValidationError({ value: _value, min, max, name });
    return _value;
  },
  maxLength: (value, { max, name }) => {
    return MalApiValidators.max(value.length, { max, name });
  },
  minLength: (value, { min, name }) => {
    return MalApiValidators.min(value.length, { min, name });
  },
  minMaxlength: (value, { min, max, name }) => {
    return MalApiValidators.minMax(value.length, { min, max, name });
  }
};

export {
  MalApiValidators
};
