import {
  Config
} from "./chunk-6H4WKCW5.js";
import {
  ApiVersion,
  MalClientEndpoint
} from "./chunk-BCMNSRGV.js";

// lib/api/endpoints/authentication.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils";
var authentication = {
  /**
   * Request an authorization code.
   * @see [authorize]{@link https://myanimelist.net/apiconfig/references/authorization#step-2-client-requests-oauth-20-authentication}
   */
  authorize: new MalClientEndpoint({
    method: HttpMethod.GET,
    url: "/oauth2/authorize",
    seed: {
      response_type: "code"
    },
    init: {
      redirect: "manual",
      credentials: "omit"
    },
    opts: {
      version: ApiVersion.v1,
      endpoint: Config.Website,
      cache: false,
      parameters: {
        query: {
          client_id: true,
          code_challenge: true,
          code_challenge_method: false,
          state: false,
          redirect_uri: false,
          response_type: true
        }
      }
    }
  }),
  token: {
    /**
     * Exchange the authorization code for an access token.
     * @see [documentation]{@link https://myanimelist.net/apiconfig/references/authorization#obtaining-oauth-20-access-tokens}
     */
    exchange: new MalClientEndpoint({
      method: HttpMethod.POST,
      url: "/oauth2/token",
      seed: {
        grant_type: "authorization_code"
      },
      opts: {
        version: ApiVersion.v1,
        endpoint: Config.Website,
        cache: false
      },
      body: {
        client_id: true,
        client_secret: true,
        code: true,
        code_verifier: true,
        redirect_uri: false,
        grant_type: true
      }
    }),
    /**
     *
     */
    refresh: new MalClientEndpoint({
      method: HttpMethod.POST,
      url: "/oauth2/token",
      seed: {
        grant_type: "refresh_token"
      },
      opts: {
        version: ApiVersion.v1,
        endpoint: Config.Website,
        cache: false
      },
      body: {
        client_id: true,
        client_secret: true,
        refresh_token: true,
        grant_type: false
      }
    })
  }
};

export {
  authentication
};
