"use strict";Object.defineProperty(exports, "__esModule", {value: true}); var _class; var _class2; var _class3; var _class4;// lib/models/mal-error.model.ts
var MalValidationErrorTypes = {
  MalApiError: "MalApiError",
  MalValidationError: "MalValidationError",
  MalNaNValidationError: "MalNaNValidationError",
  MalMinValidationError: "MalMinValidationError",
  MalMaxValidationError: "MalMaxValidationError",
  MalMinMaxValidationError: "MalMinMaxValidationError"
};
var MalErrorTypes = {
  MalInvalidParameterError: "MalInvalidParameterError",
  MalPollingExpiredError: "MalPollingExpiredError",
  MalExpiredTokenError: "MalExpiredTokenError",
  MalRateLimitError: "MalRateLimitError",
  MalInvalidCsrfError: "MalInvalidCsrfError",
  ...MalValidationErrorTypes
};
var MalApiError = class extends Error {
  /**
   * Inner error that this error wraps.
   */
  
  constructor(message, error) {
    super(message);
    this.name = MalErrorTypes.MalApiError;
    this.error = error;
  }
};
var MalValidationError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalValidationErrorTypes.MalValidationError;
  }
};
var MalNaNValidationError = (_class = class extends MalValidationError {
  __init() {this.type = MalValidationErrorTypes.MalNaNValidationError}
  constructor(value, name) {
    super(`Expected a valid number${name ? ` for '${name}'` : ""}, but received '${value}'.`);_class.prototype.__init.call(this);;
  }
}, _class);
var MalMinValidationError = (_class2 = class extends MalValidationError {
  __init2() {this.type = MalValidationErrorTypes.MalMinValidationError}
  constructor({ value, min, name }) {
    super(`Expected a number less than or equal to '${min}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);_class2.prototype.__init2.call(this);;
  }
}, _class2);
var MalMaxValidationError = (_class3 = class extends MalValidationError {
  __init3() {this.type = MalValidationErrorTypes.MalMaxValidationError}
  constructor({ value, max, name }) {
    super(`Expected a number more than or equal to '${max}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);_class3.prototype.__init3.call(this);;
  }
}, _class3);
var MalMinMaxValidationError = (_class4 = class extends MalValidationError {
  __init4() {this.type = MalValidationErrorTypes.MalMinMaxValidationError}
  constructor({ value, min, max, name }) {
    super(`Expected a number between '${min}' and '${max}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);_class4.prototype.__init4.call(this);;
  }
}, _class4);
var MalInvalidParameterError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalErrorTypes.MalInvalidParameterError;
  }
};
var MalPollingExpiredError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalErrorTypes.MalPollingExpiredError;
  }
};
var MalExpiredTokenError = class extends MalApiError {
  constructor(message, error) {
    super(message, error);
    this.name = MalErrorTypes.MalExpiredTokenError;
  }
};
var MalRateLimitError = class extends MalApiError {
  constructor(message, error) {
    super(message, error);
    this.name = MalErrorTypes.MalRateLimitError;
  }
};
var MalInvalidCsrfError = class extends Error {
  
  
  constructor({ state, expected } = {}) {
    super(`Invalid CSRF (State): expected '${expected}', but received ${state}`);
    this.name = MalErrorTypes.MalInvalidCsrfError;
    this.state = state;
    this.expected = expected;
  }
};















exports.MalValidationErrorTypes = MalValidationErrorTypes; exports.MalErrorTypes = MalErrorTypes; exports.MalApiError = MalApiError; exports.MalValidationError = MalValidationError; exports.MalNaNValidationError = MalNaNValidationError; exports.MalMinValidationError = MalMinValidationError; exports.MalMaxValidationError = MalMaxValidationError; exports.MalMinMaxValidationError = MalMinMaxValidationError; exports.MalInvalidParameterError = MalInvalidParameterError; exports.MalPollingExpiredError = MalPollingExpiredError; exports.MalExpiredTokenError = MalExpiredTokenError; exports.MalRateLimitError = MalRateLimitError; exports.MalInvalidCsrfError = MalInvalidCsrfError;
