import { MalApiResponse } from './mal-client.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const MalValidationErrorTypes: {
    readonly MalApiError: "MalApiError";
    readonly MalValidationError: "MalValidationError";
    readonly MalNaNValidationError: "MalNaNValidationError";
    readonly MalMinValidationError: "MalMinValidationError";
    readonly MalMaxValidationError: "MalMaxValidationError";
    readonly MalMinMaxValidationError: "MalMinMaxValidationError";
};
declare const MalErrorTypes: {
    readonly MalApiError: "MalApiError";
    readonly MalValidationError: "MalValidationError";
    readonly MalNaNValidationError: "MalNaNValidationError";
    readonly MalMinValidationError: "MalMinValidationError";
    readonly MalMaxValidationError: "MalMaxValidationError";
    readonly MalMinMaxValidationError: "MalMinMaxValidationError";
    readonly MalInvalidParameterError: "MalInvalidParameterError";
    readonly MalPollingExpiredError: "MalPollingExpiredError";
    readonly MalExpiredTokenError: "MalExpiredTokenError";
    readonly MalRateLimitError: "MalRateLimitError";
    readonly MalInvalidCsrfError: "MalInvalidCsrfError";
};
declare class MalApiError<T = unknown> extends Error {
    /**
     * Inner error that this error wraps.
     */
    readonly error?: Error | MalApiResponse<T>;
    constructor(message: string, error?: Error | MalApiResponse<T>);
}
declare class MalValidationError extends Error {
    constructor(message?: string);
}
declare class MalNaNValidationError extends MalValidationError {
    readonly type: "MalNaNValidationError";
    constructor(value: string | number, name?: string);
}
declare class MalMinValidationError extends MalValidationError {
    readonly type: "MalMinValidationError";
    constructor({ value, min, name }: {
        value: string | number;
        min: number;
        name?: string;
    });
}
declare class MalMaxValidationError extends MalValidationError {
    readonly type: "MalMaxValidationError";
    constructor({ value, max, name }: {
        value: string | number;
        max: number;
        name?: string;
    });
}
declare class MalMinMaxValidationError extends MalValidationError {
    readonly type: "MalMinMaxValidationError";
    constructor({ value, min, max, name }: {
        value: string | number;
        min: number;
        max: number;
        name?: string;
    });
}
declare class MalInvalidParameterError extends Error {
    constructor(message?: string);
}
declare class MalPollingExpiredError extends Error {
    constructor(message?: string);
}
declare class MalExpiredTokenError<T = unknown> extends MalApiError<T> {
    constructor(message?: string, error?: Error | MalApiResponse<T>);
}
declare class MalRateLimitError<T = unknown> extends MalApiError<T> {
    constructor(message?: string, error?: Error | MalApiResponse<T>);
}
declare class MalInvalidCsrfError extends Error {
    readonly state?: string;
    readonly expected?: string;
    constructor({ state, expected }?: {
        state?: string;
        expected?: string;
    });
}

export { MalApiError, MalErrorTypes, MalExpiredTokenError, MalInvalidCsrfError, MalInvalidParameterError, MalMaxValidationError, MalMinMaxValidationError, MalMinValidationError, MalNaNValidationError, MalPollingExpiredError, MalRateLimitError, MalValidationError, MalValidationErrorTypes };
