import { MalApiPagination, MalApiPaginatedData } from './mal-client.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

type MalForumSubBoard = {
    id: number;
    title: string;
};
type MalForumBoard = {
    id: number;
    title: string;
    description: string;
    subboards: MalForumSubBoard[];
};
type MalForumCategory = {
    title: string;
    boards: MalForumBoard[];
};
type MalForumBoardsResponse = {
    categories: MalForumCategory[];
};
type MalForumCreatedBy = {
    id: number;
    name: string;
};
type MalForumTopic = {
    id: number;
    title: string;
    created_at: string;
    created_by: MalForumCreatedBy;
    number_of_posts: number;
    last_post_created_at: string;
    last_post_created_by: MalForumCreatedBy;
    is_locked: boolean;
};
type MalForumListTopicsRequest = {
    board_id?: number;
    subboard_id?: number;
    /** Currently, only "recent" can be set. */
    sort?: 'recent' | string;
    q?: string;
    topic_user_name?: string;
    user_name?: string;
} & MalApiPagination;
type MalForumListTopicsResponse = MalApiPaginatedData<MalForumTopic>;
type MalForumPostCreatedBy = MalForumCreatedBy & {
    forum_avatar: string;
};
type MalForumPost = {
    id: number;
    number: number;
    created_at: string;
    created_by: MalForumPostCreatedBy;
    body: string;
    signature: string;
};
type MalForumPollOption = {
    id: number;
    text: string;
    votes: number;
};
type MalForumPoll = {
    id: number;
    question: string;
    close: boolean;
    options: MalForumPollOption[];
};
type MalForumTopicDetail = {
    title: string;
    posts: MalForumPost[];
    poll?: MalForumPoll[];
};
type MalForumTopicDetailRequest = {
    id: number;
} & MalApiPagination;
type MalForumTopicDetailResponse = MalApiPaginatedData<MalForumTopicDetail>;

export type { MalForumBoard, MalForumBoardsResponse, MalForumCategory, MalForumCreatedBy, MalForumListTopicsRequest, MalForumListTopicsResponse, MalForumPoll, MalForumPollOption, MalForumPost, MalForumPostCreatedBy, MalForumSubBoard, MalForumTopic, MalForumTopicDetail, MalForumTopicDetailRequest, MalForumTopicDetailResponse };
